pm4py.algo.filtering.log.start\_activities package
==================================================

Submodules
----------

pm4py.algo.filtering.log.start\_activities.start\_activities\_filter module
---------------------------------------------------------------------------

.. automodule:: pm4py.algo.filtering.log.start_activities.start_activities_filter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.log.start_activities
   :members:
   :undoc-members:
   :show-inheritance:
